chrome.runtime.onInstalled.addListener(() => {
  chrome.storage.sync.get(['apiKey', 'timeAuto', 'location'], (items) => {
    if (items.apiKey && items.timeAuto && items.location) {
      chrome.runtime.sendMessage({
        action: 'fetchCurrentProxy',
		action: 'fetchCurrentProxyView',		
        apiKey: items.apiKey,
		timeAuto: items.timeAuto,
        location: items.location
      }, response => {
        if (response.success && response.data) {
          const { ip, portsock } = response.data;

          chrome.storage.sync.set({
            proxy: {
              ip,
              portsock
            }
          });

          chrome.proxy.settings.set({
            value: {
              mode: 'fixed_servers',
              rules: {
                singleProxy: {
                  scheme: 'socks5',
                  host: ip,
                  port: parseInt(portsock)
                },
                bypassList: [
                  '*proxymxh.com',                 
                  
                ]
              }
            },
            scope: 'regular'
          }, () => {});
        } else {
          console.error(response.message || 'API key không khả dụng');
        }
      });
    }
  });
});

chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
  if (request.action === 'fetchCurrentProxy') {
    fetch(`https://proxymxh.com/api/GetCurrentextension.php?api_key=${request.apiKey}`)
      .then(response => {
        if (!response.ok) {
          // Nếu server phản hồi với lỗi HTTP, gửi thông báo lỗi
          throw new Error('Không thể lấy IP từ API');
        }
        return response.text();  
      })
      .then(text => {
        if (!text) {
          // Nếu phản hồi rỗng, gửi thông báo lỗi
          sendResponse({ success: false, message: 'Chưa lấy IP cho API' });
          return;
        }
        const data = JSON.parse(text);
        sendResponse(data);
      })
      .catch(error => sendResponse({ success: false, message: error.message }));
    return true;

  } else if (request.action === 'saveSettings') {
    chrome.storage.sync.set({ proxy: request.data }, () => {
      sendResponse({ success: true });
    });
    return true;

  } else if (request.action === 'applyProxy') {
    chrome.proxy.settings.set({
      value: {
        mode: 'fixed_servers',
        rules: {
          singleProxy: {
            scheme: 'socks5',
            host: request.data.ip,
            port: parseInt(request.data.portsock)
          },
          bypassList: [
            '*proxymxh.com',            
          ]
        }
      },
      scope: 'regular'
    }, () => {});

    // Cập nhật biểu tượng extension
    chrome.storage.sync.set({ icon: 'icon_green.png' });
    // Thêm chữ ON bằng badge
        chrome.action.setBadgeText({ text: 'On' });
        chrome.action.setBadgeBackgroundColor({ color: 'green' });
	// Lưu trạng thái proxy vào chrome.storage.sync
    chrome.storage.sync.set({ proxyStatus: 'Đã kết nối proxy' });
	// Gửi thông báo tới content script
    chrome.runtime.sendMessage({ action: 'proxyConnected', status: 'Đã kết nối proxy' });	
  } else if (request.action === 'fetchNewProxy') {
    fetch(`https://proxymxh.com/api/GetNew.php?api_key=${request.apiKey}&location=${request.location}`)
      .then(response => response.json())
      .then(data => sendResponse(data))
      .catch(error => sendResponse({ success: false, message: error.message }));
    return true;

  } else if (request.action === 'resetProxy') {
    chrome.proxy.settings.set({
      value: {
        mode: 'system'
      },
      scope: 'regular'
    }, () => {
      sendResponse({ success: true });
      
      // Cập nhật biểu tượng extension
      chrome.storage.sync.set({ icon: 'icon_main.png' });
	  chrome.action.setBadgeText({ text: 'Off' }); 
	  chrome.action.setBadgeBackgroundColor({ color: '#FF0000' });
	  // Lưu trạng thái "Chưa kết nối" vào chrome.storage.sync
      chrome.storage.sync.set({ proxyStatus: 'Trạng thái: Chưa kết nối' });
      
      // Gửi thông báo tới content script
      chrome.runtime.sendMessage({ action: 'proxyDisconnected', status: 'Chưa kết nối proxy' });
    });
    return true;
  }
});

// Đặt trạng thái biểu tượng khi khởi động
chrome.runtime.onStartup.addListener(() => {
  chrome.storage.sync.get(['icon'], (items) => {
    const iconPath = items.icon || 'icon_main.png';
    chrome.action.setIcon({ path: iconPath });
  });
});


chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
  if (request.action === 'fetchCurrentProxyView') {
    fetch(`https://proxymxh.com/api/GetCurrentextension.php?api_key=${request.apiKey}`)
      .then(response => {
        if (!response.ok) {
          throw new Error('Không thể lấy IP từ API');
        }
        return response.text();
      })
      .then(text => {
        if (!text) {
          sendResponse({ success: false, message: 'Chưa lấy IP cho API' });
          return;
        }
        const data = JSON.parse(text);
        sendResponse(data);
      })
      .catch(error => sendResponse({ success: false, message: error.message }));
    return true;

  } 
});


// Lắng nghe thay đổi biểu tượng khi extension được khởi động lại
chrome.storage.onChanged.addListener((changes) => {
  if (changes.icon) {
    chrome.action.setIcon({ path: changes.icon.newValue });
  }
});
// Gọi API và trả về kết quả khi được yêu cầu
chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
    if (request.action === 'fetchLocations') {
        fetch('https://proxymxh.com/api/get-locations.php')
            .then(response => response.json())
            .then(data => {
                sendResponse({ locations: data });
            })
            .catch(error => {
                console.error('Có lỗi xảy ra:', error);
                sendResponse({ error: error.message });
            });
        return true; // Giữ kết nối để gửi phản hồi sau khi fetch
    }
});

let currentProxy = null;

// Lấy proxy mới từ API
async function fetchNewProxy() {
    const { apiKey, location } = await new Promise((resolve) => {
        chrome.storage.sync.get(['apiKey', 'location'], (items) => {
            resolve(items);
        });
    });

    const API_URL = `https://proxymxh.com/api/GetNewextension.php?api_key=${apiKey}&location=${location}`;
    
    try {
        const response = await fetch(API_URL);
        if (!response.ok) throw new Error('Network response was not ok');
        
        const data = await response.json();
        if (data.success && data.data && data.data.ip && data.data.portsock) {
            return { ip: data.data.ip, port: data.data.portsock };
        } else {            
           
        }
    } catch (error) {        
        return null;
    }
}

// Cập nhật proxy
async function resetAndSetProxy() {
    const newProxy = await fetchNewProxy();
    if (newProxy) {
        currentProxy = newProxy;
        console.log(`Setting Proxy: ${currentProxy.ip}:${currentProxy.port}`);

        // Cập nhật cấu hình proxy
        chrome.proxy.settings.set(
            { 
                value: { 
                    mode: "fixed_servers", 
                    rules: { 
                        singleProxy: { 
                            scheme: "socks5", 
                            host: currentProxy.ip, 
                            port: parseInt(currentProxy.port) 
                        },
                        bypassList: ["proxymxh.com"]
                    } 
                }, 
                scope: "regular" 
            },
            () => {
                if (chrome.runtime.lastError) {                                    
                } else {
                    chrome.storage.sync.set({ proxyStatus: 'Đã kết nối proxy' });
                    chrome.action.setBadgeText({ text: 'Auto' });
                    chrome.action.setBadgeBackgroundColor({ color: 'green' });
                }
            }
        );
    }
}

// background.js
let countdownInterval = null; // Biến toàn cục lưu trữ ID của setInterval

// Lắng nghe thông điệp từ popup.js
chrome.runtime.onMessage.addListener((message, sender, sendResponse) => {
    if (message.action === "startTimer") {
        createAlarmBasedOnTimeAuto();
    } else if (message.action === "stopTimer") {
        clearInterval(countdownInterval); // Dừng bộ đếm thời gian
        countdownInterval = null; // Đặt lại ID của interval
        chrome.action.setBadgeText({ text: 'Stop' });
		chrome.action.setBadgeBackgroundColor({ color: 'red' });
        chrome.alarms.clear('fetchProxy'); // Hủy alarm nếu có
    }
});

// Cập nhật alarm với thời gian định kỳ theo timeAuto
async function createAlarmBasedOnTimeAuto() {
    const { timeAuto } = await new Promise((resolve) => {
        chrome.storage.sync.get(['timeAuto'], (items) => {
            resolve(items);
        });
    });

    if (timeAuto && !isNaN(timeAuto)) {
        const startTime = Date.now(); // Lưu thời gian bắt đầu
        chrome.storage.sync.set({ startTime }); // Lưu vào storage để tính toán sau

        // Hủy alarm cũ nếu có
        chrome.alarms.clear('fetchProxy', () => {
            // Tạo alarm mới với giá trị timeAuto làm chu kỳ (phút)
            chrome.alarms.create('fetchProxy', { periodInMinutes: parseInt(timeAuto) });

            // Bắt đầu hiển thị đếm ngược
            updateBadge(parseInt(timeAuto) * 60);
        });
    }
}

// Hàm cập nhật số phút còn lại lên icon
function updateBadge(durationInSeconds) {
    // Hủy bộ đếm cũ nếu tồn tại
    if (countdownInterval) {
        clearInterval(countdownInterval);
        countdownInterval = null;
    }

    countdownInterval = setInterval(() => {
        const minutes = Math.floor(durationInSeconds / 60);
        const seconds = durationInSeconds % 60;

        // Cập nhật text lên badge
        chrome.action.setBadgeText({ text: `${minutes}:${seconds < 10 ? '0' : ''}${seconds}` });
        chrome.action.setBadgeBackgroundColor({ color: 'green' });
        if (durationInSeconds <= 0) {
            clearInterval(countdownInterval);
            countdownInterval = null; // Xóa ID của interval
            chrome.action.setBadgeText({ text: '' }); // Xóa badge khi hết giờ
        } else {
            durationInSeconds -= 1;
        }
    }, 1000);
}

// Lắng nghe alarm và thực thi hành động
chrome.alarms.onAlarm.addListener(async (alarm) => {
    if (alarm.name === 'fetchProxy') {
        console.log("Alarm triggered: Fetching new proxy...");
        await resetAndSetProxy();

        // Lấy timeAuto và cập nhật lại đếm ngược
        const { timeAuto } = await new Promise((resolve) => {
            chrome.storage.sync.get(['timeAuto'], (items) => {
                resolve(items);
            });
        });

        if (timeAuto && !isNaN(timeAuto)) {
            updateBadge(parseInt(timeAuto) * 60);
        }
    }
});
