document.addEventListener('DOMContentLoaded', () => {
  // Tải cấu hình từ storage và cập nhật giao diện
  chrome.storage.sync.get(['apiKey', 'timeAuto', 'location', 'proxy', 'icon', 'countdownEndTime', 'countdownEndDie'], (items) => {
    if (items.apiKey) {
      document.getElementById('apiKey').value = items.apiKey;
    }
	if (items.timeAuto) {
      document.getElementById('timeAuto').value = items.timeAuto;
    }
    if (items.location) {
      document.getElementById('location_new').value = items.location;
    }
    if (items.proxy) {
      document.getElementById('ip').textContent = items.proxy.ip || 'N/A';
      document.getElementById('portsock').textContent = items.proxy.portsock || 'N/A';
      document.getElementById('ip_allow').textContent = items.proxy.ip_allow || 'N/A';
      document.getElementById('location').textContent = items.proxy.location || 'N/A';
    }
    if (items.icon) {
      chrome.action.setIcon({ path: items.icon });
    }

    // Hiển thị thời gian đếm lùi cho waiting_time nếu có
    if (items.countdownEndTime) {
      const countdownEndTime = new Date(items.countdownEndTime).getTime();
      const currentTime = new Date().getTime();
      const remainingTime = Math.max(0, Math.ceil((countdownEndTime - currentTime) / 1000));
      startCountdown(remainingTime);
    }

    // Hiển thị thời gian đếm lùi cho time_die nếu có
    if (items.countdownEndDie) {
      const countdownEndDie = new Date(items.countdownEndDie).getTime();
      const currentDieTime = new Date().getTime();
      const remainingTimeDie = Math.max(0, Math.ceil((countdownEndDie - currentDieTime) / 1000));
      startCountdownDie(remainingTimeDie);
    }
  });
});

  // Lưu cấu hình khi người dùng thay đổi API Key hoặc Location
  document.getElementById('apiKey').addEventListener('input', saveSettings);
  document.getElementById('timeAuto').addEventListener('input', saveSettings);
  document.getElementById('location_new').addEventListener('change', saveSettings);

  // Xử lý nút Disconnect
  document.getElementById('disconnectButton').addEventListener('click', () => {
    chrome.storage.sync.get(['apiKey', 'location'], (items) => {
      if (items.apiKey && items.location) {
        chrome.runtime.sendMessage({
          action: 'resetProxy',
          apiKey: items.apiKey,
          location: items.location
        }, response => {
          if (response.success) {
            document.getElementById('ip').textContent = 'Đã về IP gốc';
            document.getElementById('portsock').textContent = '';
            document.getElementById('ip_allow').textContent = 'Đã về IP gốc';
            document.getElementById('location').textContent = 'Đã về IP gốc';

            chrome.storage.sync.remove('proxy', () => {
              showToast('Hủy kết nối API');
            });
            chrome.storage.sync.set({ icon: 'icon_red.png' });
          } else {
            showToast(response.message || 'API không khả dụng');
          }
        });
      } else {
        showToast('API chưa được kết nối ');
      }
    });
  });

  // Xử lý nút Use Proxy
  document.getElementById('useProxyButton').addEventListener('click', () => {
    chrome.storage.sync.get(['apiKey', 'location'], (items) => {
      if (items.apiKey && items.location) {
        chrome.runtime.sendMessage({
          action: 'fetchCurrentProxy',
          apiKey: items.apiKey,
          location: items.location
        }, response => {
          if (response.success && response.data) {
            const { ip, portsock, ip_allow, location } = response.data;
            document.getElementById('ip').textContent = ip;
            document.getElementById('portsock').textContent = portsock;
            document.getElementById('ip_allow').textContent = ip_allow;
            document.getElementById('location').textContent = location;

            chrome.storage.sync.set({ proxy: { ip, portsock, ip_allow, location } }, () => {              
              chrome.runtime.sendMessage({ action: 'applyProxy', data: { ip, portsock, ip_allow, location } });
            });
          } else {
            showToast(response.message || 'API không khả dụng');
          }
        });
      } else {
        showToast('Chưa được kết nối API');
      }
    });
  });

 // Xử lý nút Change IP
document.getElementById('changeIPButton').addEventListener('click', () => {
  chrome.storage.sync.get(['apiKey', 'location'], (items) => {
    if (items.apiKey && items.location) {
      chrome.runtime.sendMessage({
        action: 'fetchNewProxy',
        apiKey: items.apiKey,
        location: items.location
      }, response => {
        if (response.success && response.data) {
          const { ip, portsock, ip_allow, location, waiting_time, time_die } = response.data;
          document.getElementById('ip').textContent = ip;
          document.getElementById('portsock').textContent = portsock;
          document.getElementById('ip_allow').textContent = ip_allow;
          document.getElementById('location').textContent = location;

          chrome.storage.sync.set({ proxy: { ip, portsock, ip_allow, location } }, () => {           
            chrome.runtime.sendMessage({ action: 'applyProxy', data: { ip, portsock, ip_allow, location } });

            // Tính thời gian đếm lùi cho waiting_time
            const countdownEndTime = new Date().getTime() + waiting_time * 1000;
            chrome.storage.sync.set({ countdownEndTime }, () => {
              startCountdown(waiting_time);
            });

            // Tính thời gian đếm lùi cho time_die
            if (time_die) {
              const countdownEndDie = new Date().getTime() + time_die * 1000;
              chrome.storage.sync.set({ countdownEndDie }, () => {
                startCountdownDie(time_die);
              });
            }
          });
        } else {
          showToast(response.message || 'API không khả dụng');
        }
      });
    } else {
      showToast('Chưa được kết nối API');
    }
  });
});


document.getElementById('changeIPButtonshow').addEventListener('click', () => {
  chrome.storage.sync.get(['apiKey', 'location'], (items) => {
    if (items.apiKey && items.location) {
      chrome.runtime.sendMessage({
        action: 'fetchCurrentProxyView',
        apiKey: items.apiKey,
        location: items.location
      }, response => {
        if (response.success && response.data) {
          const { ip, portsock, ip_allow, location, waiting_time, time_die } = response.data;
          document.getElementById('ip').textContent = ip;
          document.getElementById('portsock').textContent = portsock;
          document.getElementById('ip_allow').textContent = ip_allow;
          document.getElementById('location').textContent = location;
          chrome.storage.sync.set({ proxy: { ip, portsock, ip_allow, location } }, () => {     
            

            // Tính thời gian đếm lùi cho waiting_time
            const countdownEndTime = new Date().getTime() + waiting_time * 1000;
            chrome.storage.sync.set({ countdownEndTime }, () => {
              startCountdown(waiting_time);
            });

            // Tính thời gian đếm lùi cho time_die
            if (time_die) {
              const countdownEndDie = new Date().getTime() + time_die * 1000;
              chrome.storage.sync.set({ countdownEndDie }, () => {
                startCountdownDie(time_die);
              });
            }
          });
        } else {
          showToast(response.message || 'API không khả dụng');
        }
      });
    } else {
      showToast('Chưa được kết nối API');
    }
  });
});

function startCountdown(remainingTime) {
  let countdownElement = document.getElementById('countdown');
  
  if (!countdownElement) {
    countdownElement = document.createElement('p');
    countdownElement.id = 'countdown';
    countdownElement.innerHTML = `<i class='fas fa-exchange-alt'></i> Được đổi IP sau: <span style="color: red;">${remainingTime}</span>s`;
    document.getElementById('location').parentNode.insertBefore(countdownElement, document.getElementById('location').nextSibling);
  } else {
    countdownElement.innerHTML = `<i class='fas fa-exchange-alt'></i> Được đổi IP sau: <span style="color: red;">${remainingTime}</span>s`;
  }

  const countdownInterval = setInterval(() => {
    if (remainingTime <= 0) {
      clearInterval(countdownInterval);
      countdownElement.innerHTML = `<i class='fas fa-redo'></i> Được phép đổi IP`;
    } else {
      countdownElement.innerHTML = `<i class='fas fa-exchange-alt'></i> Được đổi IP sau: <span style="color: red;">${remainingTime}</span>s`;
      remainingTime--;
    }
  }, 1000);
}

// Hàm để bắt đầu đếm lùi thời gian cho time_die
function startCountdownDie(remainingTimeDie) {
  let countdownDieElement = document.getElementById('countdownDie');
  
  if (!countdownDieElement) {
    countdownDieElement = document.createElement('p');
    countdownDieElement.id = 'countdownDie';
    countdownDieElement.innerHTML = `<i class='fas fa-history'></i> Thời gian hết hạn IP: <span style="color: red;">${remainingTimeDie}</span>s`;
    document.getElementById('location').parentNode.insertBefore(countdownDieElement, document.getElementById('countdown').nextSibling);
  } else {
    countdownDieElement.innerHTML = `<i class='fas fa-history'></i> Thời gian hết hạn IP: <span style="color: red;">${remainingTimeDie}</span>s`;
  }

  const countdownDieInterval = setInterval(() => {
    if (remainingTimeDie <= 0) {
      clearInterval(countdownDieInterval);
      countdownDieElement.innerHTML = 'IP đã hết hạn';

      // Xóa nội dung của các phần tử khi IP đã hết hạn
      document.getElementById('ip').textContent = '';
      document.getElementById('portsock').textContent = '';
      document.getElementById('ip_allow').textContent = '';
      document.getElementById('location').textContent = '';

    } else {
      countdownDieElement.innerHTML = `<i class='fas fa-history'></i> Thời gian hết hạn IP: <span style="color: red;">${remainingTimeDie}</span>s`;
      remainingTimeDie--;
    }
  }, 1000);
}

  // Lưu cài đặt vào chrome.storage
  function saveSettings() {
    const apiKey = document.getElementById('apiKey').value;
	const timeAuto = document.getElementById('timeAuto').value;
    const location = document.getElementById('location_new').value;

    chrome.storage.sync.set({ timeAuto, apiKey, location }, () => {
      showToast('Saved');
    });
  }

  // Hiển thị thông báo (toast)
  function showToast(message) {
    const toast = document.getElementById('toast');
    toast.textContent = message;
    toast.className = 'toast show';
    setTimeout(() => {
      toast.className = 'toast';
    }, 1000);
  }


        document.addEventListener('DOMContentLoaded', function() {
            const selectElement = document.getElementById('location_new');

            // Gửi yêu cầu lấy dữ liệu từ background.js
            chrome.runtime.sendMessage({ action: 'fetchLocations' }, (response) => {
                if (response.locations) {
                    response.locations.forEach(location => {
                        const option = document.createElement('option');
                        option.value = location.id;
                        option.textContent = `${location.id}. ${location.name}`;
                        selectElement.appendChild(option);
                    });
                } else {
                    console.error('Có lỗi xảy ra:', response.error);
                }
            });
        });

// Hàm gọi API và cập nhật thẻ <select>
    function fetchAndUpdateLocations() {
        chrome.runtime.sendMessage({ action: 'fetchLocations' }, function(response) {
            if (response.locations) {
                const selectElement = document.getElementById('location_new');
                selectElement.innerHTML = ''; 
                // Lấy giá trị đã lưu
                const savedLocation = localStorage.getItem('selectedLocation');

                // Thêm các tùy chọn từ dữ liệu nhận được
                response.locations.forEach(location => {
                    const option = document.createElement('option');
                    option.value = location.id; // Giả sử id là thuộc tính của location
                    option.textContent = `${location.id}. ${location.name}`; // Tên hiển thị
                    selectElement.appendChild(option);
                });

                // Đặt lại lựa chọn cho thẻ <select> dựa trên giá trị đã lưu
                if (savedLocation) {
                    selectElement.value = savedLocation; // Đặt giá trị thẻ <select> theo giá trị đã lưu
                }
            }
        });
    }

    window.onload = () => {
    fetchAndUpdateLocations();
    document.getElementById('changeIPButtonshow').click();
};

    // Lưu lựa chọn vào Local Storage khi thay đổi
    document.getElementById('location_new').addEventListener('change', function() {
        localStorage.setItem('selectedLocation', this.value);
    });
   

	


 // Lấy trạng thái proxy từ chrome.storage.sync khi trang được tải
    chrome.storage.sync.get('proxyStatus', (result) => {
      if (result.proxyStatus) {
        updateStatus(result.proxyStatus);
      }
    });

    // Hàm cập nhật trạng thái
    function updateStatus(status) {
      const statusValue = document.querySelector("#proxyStatus .status-value");
      if (status === 'Đã kết nối proxy') {
        statusValue.style.color = '#00bfff';  // Màu xanh khi đã kết nối
      } else {
        statusValue.style.color = 'red';    // Màu đỏ khi chưa kết nối
      }
      statusValue.textContent = status;
    }

    // Lắng nghe thông báo từ background script
    chrome.runtime.onMessage.addListener((message) => {
      if (message.action === 'proxyConnected' || message.action === 'proxyDisconnected') {
        updateStatus(message.status);
        chrome.storage.sync.set({ proxyStatus: message.status });
      }
    });
	
	
	
// popup.js
let countdownInterval = null; // Biến toàn cục lưu trữ ID của setInterval
let isTimerActive = false; // Biến kiểm tra trạng thái của bộ đếm giờ

// Lắng nghe sự kiện click của nút
document.getElementById('toggleTimerBtn').addEventListener('click', () => {
    if (isTimerActive) {
        // Tắt chế độ hẹn giờ
        chrome.runtime.sendMessage({ action: "stopTimer" });
        isTimerActive = false;
    } else {
        // Bắt đầu chế độ hẹn giờ
        chrome.runtime.sendMessage({ action: "startTimer" });
        isTimerActive = true;
    }
});


// Xóa giá trị khi input được click vào
document.getElementById("timeAuto").addEventListener("focus", function() {
    var input = this;
    if (input.value === "Nhập số phút") {
        input.value = ""; // Xóa chữ "Nhập số phút" khi input được focus
    }
});

// Khôi phục giá trị khi input không có giá trị
document.getElementById("timeAuto").addEventListener("blur", function() {
    var input = this;
    if (input.value === "") {
        input.value = "Nhập số phút"; // Khôi phục chữ "Nhập số phút" khi không có gì nhập vào
    }
});
